__all__ = [
    "__author__",
    "__copyright__",
    "__email__",
    "__license__",
    "__summary__",
    "__title__",
    "__uri__",
    "__version__",
]

__title__ = "torxtools"
__summary__ = "Less generic functionalities than Phillips and Pozidriv tools."
__uri__ = "https://gitlab.com/jlecomte/projects/python/torxtools"

__version__ = "0.14.2"

__author__ = "Julien Lecomte"
__email__ = "julien@lecomte.at"

__license__ = "MIT"
__copyright__ = f"2020-2022 {__author__}"
